@@ -37,6 +37,7 @@ Usage::
         DescribeImportImageTasksPaginator,
         DescribeImportSnapshotTasksPaginator,
         DescribeInstanceCreditSpecificationsPaginator,
+        DescribeInstanceEventWindowsPaginator,
         DescribeInstanceStatusPaginator,
         DescribeInstanceTypeOfferingsPaginator,
         DescribeInstanceTypesPaginator,
@@ -211,6 +212,7 @@ Usage::
     describe_import_image_tasks_paginator: DescribeImportImageTasksPaginator = client.get_paginator("describe_import_image_tasks")
     describe_import_snapshot_tasks_paginator: DescribeImportSnapshotTasksPaginator = client.get_paginator("describe_import_snapshot_tasks")
     describe_instance_credit_specifications_paginator: DescribeInstanceCreditSpecificationsPaginator = client.get_paginator("describe_instance_credit_specifications")
+    describe_instance_event_windows_paginator: DescribeInstanceEventWindowsPaginator = client.get_paginator("describe_instance_event_windows")
     describe_instance_status_paginator: DescribeInstanceStatusPaginator = client.get_paginator("describe_instance_status")
     describe_instance_type_offerings_paginator: DescribeInstanceTypeOfferingsPaginator = client.get_paginator("describe_instance_type_offerings")
     describe_instance_types_paginator: DescribeInstanceTypesPaginator = client.get_paginator("describe_instance_types")
@@ -316,6 +318,7 @@ from .paginator import (
     DescribeImportImageTasksPaginator,
     DescribeImportSnapshotTasksPaginator,
     DescribeInstanceCreditSpecificationsPaginator,
+    DescribeInstanceEventWindowsPaginator,
     DescribeInstancesPaginator,
     DescribeInstanceStatusPaginator,
     DescribeInstanceTypeOfferingsPaginator,
@@ -467,6 +470,7 @@ __all__ = (
     "DescribeImportImageTasksPaginator",
     "DescribeImportSnapshotTasksPaginator",
     "DescribeInstanceCreditSpecificationsPaginator",
+    "DescribeInstanceEventWindowsPaginator",
     "DescribeInstanceStatusPaginator",
     "DescribeInstanceTypeOfferingsPaginator",
     "DescribeInstanceTypesPaginator",
